@@ -33,7 +33,7 @@ extern "C" {
 #define MagickLibAddendum  "-24"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
-#define MagickPlatform  "x86_64"
+#define MagickPlatform  "i686"
 #define MagickppLibVersionText  "7.1.1"
 #define MagickppLibVersionNumber  5:0:0
 #define MagickppLibAddendum  "-24"
